function c = cortex (sfile, clusters, varargin)

% @CORTEX/CORTEX   the @cortex class constructor
% 
%  CORTEX(FILENAME,CLUSTERS) Creates and returns a @cortex object
%     from the CORTEX data file specified by FILENAME. The mandatory
%     CLUSTERS argument is a numeric vector specifying a set of event
%     codes that should be interpreted as spikes whenever they appear
%     during a trial.
% 
%  CORTEX(FILENAME) If the filename extension is 'nex' then the
%     object is  created from a .nex file, otherwise the object is
%     created from a @cortex-optimized "dump" file previously created
%     with the SAVE method.
% 
%  CORTEX without arguments creates an "empty" @cortex object
%
% Last modified: 15 Feb 06

% 21 Apr 99: changemode field added
% 11 Jun 99: version #, rel_trial added
% 26 Aug 99: avoid warning for 0-event trials
% 21 May 00: help text and comments
%            EyePos stuff integrated into object!
%            Ver.2
% 24 May 00: help text revised
%  1 Aug 02: this function only parses arguments; specific
%            functions in 'private' called from here
% 10 Oct 02: end of @newcortex testing phase
% 30 Nov 02: help bits
%  5 Feb 04: fixed bug found by Bjoerg
%            (secondarg missing in case 3 and 4)
% 28 Sep 04: complete rewrite, mainly to accommodate giucode.def
%  6 Nov 04: GiuCoDefaultValues implemented;
%            argument list fixed; help text revised
% 12 Nov 04: help text
% 15 Feb 06: getdefs introduced

gd = getdefs;
verbose = gd.general.verbose;

if nargin==0
   if verbose, disp ('creating empty @cortex object'); end
   c = emptycobject;
else
   [pa, na, ex] = fileparts (sfile);
   if strcmp (ex, '.nex')
      if isempty (gd.nex), error ('missing [nex] section in giucode.def'); end
      if verbose, disp ('creating @cortex object from .nex file...'); end
      if nargin>1, warning ('all arguments except 1st will be ignored'); end
      c = loadnex (sfile);
   else
      if nargin==1
         if verbose, disp ('creating @cortex object from dump file...'); end
         c = loadump (sfile);
      else
         if verbose, disp ('creating @cortex object from raw CORTEX data file...'); end
         if nargin>2
            s = sprintf ('all arguments except first 2 will be ignored;\nuse giucode.def to specify EOG parameters.');
            warning (s);
         end
         c = loadraw (sfile, clusters);
      end
   end
end
c=class(c, 'cortex');