function dh = densityplot (c, cluster, keys, varargin)

%@CORTEX/DENSITYPLOT  spike density plots from a @cortex object
%
%   DENSITYPLOT(COBJ,CLUSTER,KEYS) plots the spike density function
%   obtained for spike CLUSTER from the COBJ @cortex object, for the trials
%   and over the time window specified by the KEYS.
%
%   The smoothing algorithm uses a kernel of given width (in ms) and shape.
%   Currently implemented kernels are 'boxcar', 'gauss', and 'epsp'. By
%   default, the function uses the values stored in giucode.def. One or
%   both parameters, however, can be specified as follows:
%   DENSITYPLOT (COBJ,CLUSTER,KEYS,KERNELWIDTH,KERNELTYPE)
%
% Last modified: 22 Feb 06

% Released: 22 Feb 06

error (NOTscalar(cluster));
error (NOTkey(keys));
xr = keys(1).start:keys(1).finish-1;
dall = [];
for k = 1:keys.len
	spmat = spikematrix (c, cluster, keys(k));
	d = meanfiringdensity (spmat, varargin{:});
	dall = [dall; d];
end
h = plot (xr, dall);
ym = max(max(dall));
ymax = max (10, ceil (ym/10)*10);
set (gca, 'xlim', [xr(1) xr(end)], 'ylim', [0 ymax]);
if nargout, dh=h; end