function [ts, mval] = nexf_mark(fid, header_offset)
% Read marker variable from a .nex file
%
% [ts, mval] = nex_marker(fid, header_offset)
%
% INPUT:
%   fid - fileID
%   header_offset - header offset of the marker variable
%
%           continuous (a/d) data come in fragments. Each fragment has a timestamp
%           and a number of a/d data points. The timestamp corresponds to
%           the time of recording of the first a/d value in this fragment.
%           All the data values stored in the vector d. 
% OUTPUT:
%   ts - array of marker timestamps
%   mval - number array of marker values

%nm - number of fields in each marker
%nl - number of characters in each marker field

n=0; nm=0; nl=0; ts=0; m=0;

fseek(fid, header_offset+72, 'bof');
data_offset = fread(fid, 1, 'int32');
n = fread(fid, 1, 'int32');
dummy = fread(fid, 32, 'char');
adfreq = fread(fid, 1, 'double');
adtomv = fread(fid, 1, 'double');
npw = fread(fid, 1, 'int32');
nm = fread(fid, 1, 'int32');
nl = fread(fid, 1, 'int32');
fseek(fid, data_offset, 'bof');
ts = fread(fid, [1 n], 'int32');
names = zeros(1,64);
mval = zeros(1,n);
for j=1:nm
    names(j, :) = fread(fid, [1 64], 'char');
    for p = 1:n
        m = fread(fid, [1 nl], 'char');
        mval(1,p)=str2num(setstr(m));
    end
end
