function sp = deleteunit (sp, u)

%SPIX/DELETEUNIT  permanently deletes a unit from a @spix
%
%   SP = DELETEUNIT(SP,U) removes the unit specified in U from the SP
%   @spix object. U can be either the unit's index or its label. The
%   user must type the string 'yes' at the prompt to confirm. As an
%   extra safety measure, the unit must be excluded first.
%
%   CAUTION: if unit X is removed, all unit indices >X shift back by
%   one. Thus, code that refers to specific units by their index#
%   within the @spix object may become unreliable.
%
%Last modified: 27 Nov 04

% first release: 27 Nov 04

if nargin ~= 2, error ('two arguments required'); end

uni = parsegrouping (sp.info, u);
if length(uni)>1, error ('you can only delete one unit at a time'); end
uname = sp.info(uni).label;
if any (sp.inclunits==uni), error ('a unit must must be excluded in order to be deleted'); end
disp (['WARNING! This will delete unit #' num2str(uni) ' (' uname ') from the spix']);
sure = input ('Type ''yes'' if you want to proceed: ','s');
if ~strcmp(sure, 'yes'), return; end

disp (['deleting unit ''' uname ''' from ' sp.name ' @spix object']);
deltrials = sp.unit==uni;

sp.nunits = sp.nunits - 1;
sp.info (uni) = [];
sp.spix (deltrials,:) = [];
sp.key  (deltrials)   = [];
sp.trial(deltrials)   = [];
sp.yest (deltrials)   = [];
sp.unit (deltrials)   = [];

id = find (sp.unit > uni);
sp.unit(id) = double(sp.unit(id)) - 1;
id = find (sp.inclunits > uni);
sp.inclunits(id) = sp.inclunits(id)-1;

for su = 1:length(sp.subsets)
   st = sp.subsets(su);
   du = find (st.units == uni);
   if ~isempty(du)
      disp (['removing unit ''' uname ''' from subset ''' st.label '''']);
      st.units(du) = [];
      if isempty (st.units)
         disp (['removing empty subset ''' st.label '''']);
         sp.subsets(su)=[];
         sp.nsubs = sp.nsubs - 1;
      else
         id = find (st.units > uni);
         st.units(id) = st.units(id) - 1;
         sp.subsets(su).units = st.units;
      end
   end
end