function varargout = cortview(varargin)
% CORTVIEW  simple GUI for @cortex object browsing
%
%   CORTVIEW(CO) creates a GUI figure that shows header values, behavioral
%   encodes, and spikes for each trial in the CO @cortex object.
%
%   CORTVIEW(CO,K) also loads the K @key object. Click on one of the key
%   labels in the bottom left list box in order to restrict browsing to
%   specific subsets of trials.
%
%   Note that you can also invoke CORTVIEW using the two following
%   @cortex dot-property syntax forms:
%   >> CO.VIEW;
%   >> CO.VIEW(K);
%
% Last modified: 3 Dec 04

% Edit the above text to modify the response to help cortview

% Last Modified by GUIDE v2.5 09-Feb-2006 12:07:12

% Begin initialization code - DO NOT EDIT
gui_Singleton = 0;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @cortview_OpeningFcn, ...
                   'gui_OutputFcn',  @cortview_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin & isstr(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before cortview is made visible.
function cortview_OpeningFcn(hObject, eventdata, handles, varargin)

kwarn = {};
kl = {'All trials'};
handles.c = varargin{1};
if ~isa (handles.c, 'cortex'), error ('@cortex object needed'); end
if length(varargin)>1
   k = varargin{2};
   if ~isa (k, 'key'), error ('@key object needed'); end
   for i=1:k.len
      ts = trialset (handles.c, k(i));
      if isempty(ts)
         kwarn = [kwarn; {k(i).lab}];
      else
         kl = [kl {k(i).lab}];
      end
   end
   set (handles.lstKeys, 'string', kl);
   handles.k = k;
   if ~isempty (kwarn)
      warning ('The following keys were discarded because they do not match any trials:');
      disp (kwarn);
   end
else
   set (handles.lstKeys, 'string', 'No keys loaded');
end
set (handles.figure1, 'name', handles.c.name);
handles.vtrials = 1:handles.c.trials; % current valid trials array
handles.vtridx = 1; % current valid trials index
set (handles.tTrial, 'string', 1);
UpdateScreen (handles);

% Choose default command line output for cortview
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% --- Outputs from this function are returned to the command line.
function varargout = cortview_OutputFcn(hObject, eventdata, handles)
varargout{1} = handles.output;

% --- Executes on selection change in lstCodes.
function lstCodes_Callback(hObject, eventdata, handles)

% --- Executes on selection change in lstSpikes.
function lstSpikes_Callback(hObject, eventdata, handles)

% --- Executes on button press in cmdFirst.
function cmdFirst_Callback(hObject, eventdata, handles)
set (handles.tTrial, 'string', handles.vtrials(1));
handles.vtridx = 1;
guidata(hObject, handles);
UpdateScreen (handles);

% --- Executes on button press in cmdPrev.
function cmdPrev_Callback(hObject, eventdata, handles)
idx = max (1, handles.vtridx - 1);
set (handles.tTrial, 'string', handles.vtrials (idx));
handles.vtridx = idx;
guidata(hObject, handles);
UpdateScreen (handles);

% --- Executes on button press in cmdNext.
function cmdNext_Callback(hObject, eventdata, handles)
idx = min (length(handles.vtrials), handles.vtridx + 1);
set (handles.tTrial, 'string', handles.vtrials (idx));
handles.vtridx = idx;
guidata(hObject, handles);
UpdateScreen (handles);

% --- Executes on button press in cmdLast.
function cmdLast_Callback(hObject, eventdata, handles)
set (handles.tTrial, 'string', handles.vtrials(end));
handles.vtridx = length(handles.vtrials);
guidata(hObject, handles);
UpdateScreen (handles);

function tTrial_Callback(hObject, eventdata, handles)
ct = max (1, min(uivalue(hObject), handles.c.tri));
ids = find (handles.vtrials <= ct); % smaller id's
if isempty (ids)
   idb = find (handles.vtrials > ct);
   handles.vtridx = min (idb);
else
   handles.vtridx = max (ids);
end
nt = handles.vtrials(handles.vtridx);
set (handles.tTrial, 'string', nt);
guidata(hObject, handles);
UpdateScreen (handles);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function UpdateScreen (handles)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ct = uivalue (handles.tTrial);
c  = handles.c;
set (handles.tRel, 'string', c.rel(ct));
set (handles.tCnd, 'string', c.con(ct));
set (handles.tBlo, 'string', c.blo(ct));
set (handles.tRep, 'string', c.rep(ct));
set (handles.tEOG, 'string', c.eog(ct));
set (handles.tKHz, 'string', c.khz(ct));
set (handles.tTyp, 'string', c.typ(ct));
set (handles.tGiv, 'string', c.giv(ct));
set (handles.tRes, 'string', c.res(ct));
set (handles.tSpikes, 'string', length(trialspikes(c, ct)));
try
	[eX, eY] = trialeogs (c, ct);
catch
	eX = [];
end
nEOGs = length(eX);
set (handles.tEOGs, 'string', nEOGs);

try
	[pX, pY] = trialepps (c, ct);
catch
	pX = [];
end
nEPPs = length(pX);
set (handles.tEPPs, 'string', nEPPs);

try
    [tX tY tD tU] = trialtouch (c, ct, 'mean');
catch
    tX = [];
end
nTouch = length(tX);
set (handles.tTchs, 'string', nTouch);
% set up lstCodes
% the weird formatting technique is due to the fact that
% num2str chops off trailing columns of blanks
if ~isempty (c.codes)
    idx = find (c.codes(ct,:));
    nix = length (idx);
    pro = [1:nix]';
    tmp = c.times(ct,idx)';
    dif = [0; diff(tmp)];
    t = num2str ([pro tmp dif c.codes(ct,idx)'], '+%3d%6d%6d%6d');
    set (handles.lstCodes, 'string', t(:,2:end));
end

% set up lstSpikes
[ts cl] = trialspikes (c, ct);
clu = num2str (cl); [hi w1] = size(clu);
tim = num2str (ts); w2 = size(tim,2);
spc = repmat(' ', hi, 2);
sss = [clu, spc, tim];
if isempty (sss)
   set (handles.lstSpikes, 'string', '#    ms');
else
   head = repmat (' ', 1, size(sss,2));
   head (w1) = '#';
   head (end-1:end) = 'ms';
   set (handles.lstSpikes, 'string', [head; sss]);
end

if ~uicheckedmenu(handles.analogs), return; end

% set up lstEOG
if nEOGs
	t = num2str ([eX' eY'], '%.3f ');
	set (handles.lstEOG, 'string', t);
end

% set up lstEPP
if nEPPs
    t = num2str ([pX pY]);
	set (handles.lstEPP, 'string', t);
end

% set up lstTouch
if nTouch
    t = num2str ([tD tU tX tY], '%7d%7d%7d%7d');
    set (handles.lstTouch, 'string', t);
end

% --- Executes on selection change in lstKeys.
function lstKeys_Callback(hObject, eventdata, handles)
ck = get (hObject, 'value');
if ck==1
   handles.vtrials = 1:handles.c.trials;
else
   kl = get(hObject, 'string');
   handles.vtrials = trialset (handles.c, handles.k(kl{ck}));
end
handles.vtridx = 1;
set (handles.tTrial, 'string', handles.vtrials(1));
guidata(hObject, handles);
UpdateScreen(handles);

% --------------------------------------------------------------------
function analogs_Callback(hObject, eventdata, handles)
pos = get (handles.figure1, 'position');
state = uimenucheck (hObject);
if state, pos(3) = 710; else pos(3) = 475; end
set (handles.figure1, 'position', pos);

% --------------------------------------------------------------------
function close_Callback(hObject, eventdata, handles)
close (handles.figure1);

% --- Executes on selection change in lstEOG.
function lstEOG_Callback(hObject, eventdata, handles)
% --- Executes during object creation, after setting all properties.
function lstEOG_CreateFcn(hObject, eventdata, handles)
% --- Executes on selection change in lstEPP.
function lstEPP_Callback(hObject, eventdata, handles)
% --- Executes during object creation, after setting all properties.
function lstEPP_CreateFcn(hObject, eventdata, handles)
% --- Executes on selection change in lstTouch.
function lstTouch_Callback(hObject, eventdata, handles)
% --- Executes during object creation, after setting all properties.
function lstTouch_CreateFcn(hObject, eventdata, handles)
% --------------------------------------------------------------------
function Cortview_Callback(hObject, eventdata, handles)
