function dense = meanfiringdensity (spmat, kwidth, ktype)

% MEANFIRINGDENSITY   spike density vectors
%    D = MEANFIRINGDENSITY(SPMAT) returns a vector of spike density values
%    computed from the SPMAT spikematrix.
%
%    The smoothing algorithm uses a kernel of given width (in ms) and shape.
%    Currently implemented kernels are 'boxcar', 'gauss', and 'epsp'.
%    By default, the function uses the values stored in giucode.def.
%    One or both parameters, however, can be specified as follows:
%    MEANFIRINGDENSITY (SPMAT, KERNELWIDTH, KERNELTYPE)
%
%    If either a @cortex object or a @spix object is the first parameter of
%    a MEANFIRINGDENSITY call, then the corresponding overloaded function
%    is called first. Click on link below for details.
%
% Last modified: 22 Feb 06

% 22 Feb 06: replaces density.m
%            GiuCoDefaultValues introduced; calling smooth (general purpose
%            function) instead of smoothfr.

error (NOTspikematrix(spmat));
dd = getdefs ('spikes');
if nargin < 3, ktype  = dd.density_kernel_type;  end
if nargin < 2, kwidth = dd.density_kernel_width; end
raw = sum (spmat,1) / size (spmat,1) * 1000;
dense = smooth (raw, kwidth, ktype);
