function frates = trialfiringrate (spmat, binsize)

%TRIALFIRINGRATE Trial-by-trial firing rates from a spike matrix.
%   TRIALFIRINGRATE(SPMAT) returns an array of spike/second rates, one
%   for each of the rows in the SPMAT spike matrix. Note that any NaNs
%   in SPMAT will be treated as missing values.
%
%   TRIALFIRINGRATE(SPMAT,BINSIZE) The spike matrix is subdivided into
%   BINSIZE-ms bins; firing rates are then computed for each of the
%   bins and returned as an M-by-N matrix, where M is the number of
%   rows in SPMAT and N is the number of bins.
%
%Last modified: 10 Nov 04

% 17 Apr 00: last unnoted changes
% 14 Jul 00: help text fixes
% 11 Nov 02: overloaded function
% 16 Apr 03: help text; nargin stuff rewritten
% 17 Apr 03: call to truncspm
% 27 Oct 04: cosmetics
% 10 Nov 04: help text; allow NaN-padded spmats

if nargin==1, binsize = size (spmat, 2); end
% fix and get info on spmat
[spmat, instances, winsize, numofbins] = truncspm (spmat, binsize);
% compute the firing rates
s1 = reshape(spmat, instances, binsize, numofbins);
s2 = permute (s1, [2 1 3]);
s3 = nanmean (s2) * 1000;
frates  = squeeze (s3);