function as = addata (as, levels, data)

%@FACTS/ADDATA adds observations to a @facts object
%
%   F = ADDATA(F,LEVELS,DATA) adds to F the set of observations
%   contained in the numeric vector DATA; LEVELS specifies the levels
%   associated to the data (one level per factor, obviously). LEVELS can be
%   either a numeric vector or a cell array of strings.
%
%   Note that the object variable must appear both as the first input
%   argument and as the output.
%
%Last modified: 10 Mar 06

% handle data
error (NOTnumvector (data));
as.D = [as.D; data(:)];

% handle levels
if isnumeric (levels)
	error (NOTnumvector(levels));
	levels = num2cell (levels);
elseif ~iscell(levels)
	error ('LEVELS must be either a numeric vector or a cell array');
end
if length (levels) ~= as.N
   error  (['wrong number of levels: this is a ' num2str(as.N) '-factor @fact object']);
end

for ii = 1:as.N
	lev = levels{ii};
	ln = length (as.L{ii});
	if ischar(lev)
		m = strmatch (lev, as.L{ii});
		if isempty (m)
			warning (['adding new level "' lev '" to factor "' as.F{ii} '"']);
			m = ln+1;
			as.L{ii}{m} = lev;
		end
	else
		if lev < 1
			error ('level number must be >0');
		elseif lev > ln
			m = ln + 1;
			warning (['adding level ' num2str(m) ' to factor "' as.F{ii} '"']);
			as.L{ii}{m} = sprintf ('level%02d', m);
		else
			m = lev
		end
	end
   rr = repmat (as.L{ii}(m), length(data), 1);
   as.G {ii} = [as.G{ii}; rr];
end
if as.verbose, info (as); end
