function [h b] = stderr (as, b)

% @FACTS/STDERR  standard error bars on bar charts
%     STDERR(AS,B) adds standard error bars on a previously created
%     bar chart based on the AS @facts object. B is the array of handles
%     to the barseries returned by BAR(AS).
%
%     STEDERR(AS) creates a bar chart from the AS @facts object and then
%     adds standard error bars.
%
%     STDERR(..., LineSpec)   draws the standard error bars using the
%     line type, marker symbol, and color as in errorbar.m
%
%     H=STDERR(...) returns the handles to the errorbar objects
%     [H B]=STDEV(...) also returns the barseries handles (useful if STDERR
%     is used to generate the bar chart).
%
%Last modified: 05 Feb 06

if nargin == 1
	% if no hggroup handles are passed, then create a new bar chart
	b = bar (as);
else
	b = varargin{1};
	varargin(1)=[];
	if ishandle(b)
		if ~strcmp (get(b(1), 'type'), 'hggroup')
			error ('invalid argument: handle to barseries expected');
		end
	else
		b = bar (as);
	end
end


if as.N > 2, error ('bar charts of @facts objects with more than 2 factors are not supported'); end
[mm, sd, se, gl] = descriptive(as);
h = barerr (horzarray(b), 0, se, varargin{:});
